@@ -1,18 +1,18 @@
 package Pinto::Common;
 
-# ABSTRACT: Common modules for the pinto-* utilities
+# ABSTRACT: Common libraries for the L<Pinto> suite
 
 use strict;
 use warnings;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_002'; # VERSION
+our $VERSION = '0.065_01'; # VERSION
 
 #------------------------------------------------------------------------------
 1;
 
-
+__END__
 
 =pod
 
@@ -22,17 +22,17 @@ placeholders metacpan
 
 =head1 NAME
 
-Pinto::Common - Common modules for the pinto-* utilities
+Pinto::Common - Common libraries for the L<Pinto> suite
 
 =head1 VERSION
 
-version 0.040_002
+version 0.065_01
 
 =head1 DESCRIPTION
 
 This distribution exists to provide modules that are used across
-L<pinto-admin>, L<pinto-server>, and L<pinto-remote>.  There are no
-user-serviceable parts in this distribution.
+L<pinto> and L<pintod>.  There are no user-serviceable parts in
+this distribution.
 
 =head1 SUPPORT
 
@@ -114,8 +114,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
