@@ -11,19 +11,28 @@ use overload ('""' => 'to_string');
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_002'; # VERSION
+our $VERSION = '0.065_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
+
 has author => (
     is       => 'ro',
     isa      => AuthorID,
-    coerce   => 1,
     required => 1,
 );
 
 
-has basename => (
+has author_canonical => (
+    is       => 'ro',
+    isa      => Str,
+    init_arg => undef,
+    default  => sub { uc $_[0]->author },
+    lazy     => 1,
+);
+
+
+has archive => (
     is       => 'ro',
     isa      => Str,
     required => 1,
@@ -47,13 +56,13 @@ around BUILDARGS => sub {
         my @path_parts = split m{/+}x, $args[0];
 
         my $author   = shift @path_parts;  # First element
-        my $basename = pop @path_parts;    # Last element
+        my $archive  = pop @path_parts;    # Last element
         my $subdirs  = [ @path_parts ];    # Everything else
 
         confess "Invalid distribution spec: $args[0]"
-            if not ($author and $basename);
+            if not ($author and $archive);
 
-        @args = (author => $author, subdirs => $subdirs, basename => $basename);
+        @args = (author => $author, subdirs => $subdirs, archive => $archive);
     }
 
     return $class->$orig(@args);
@@ -66,15 +75,15 @@ around BUILDARGS => sub {
 sub path {
     my ($self) = @_;
 
-    my $author   = $self->author;
+    my $author   = $self->author_canonical;
     my @subdirs  = @{ $self->subdirs };
-    my $basename = $self->basename;
+    my $archive  = $self->archive;
 
     return join '/', substr($author, 0, 1),
                      substr($author, 0, 2),
                      $author,
                      @subdirs,
-                     $basename;
+                     $archive;
 }
 
 #------------------------------------------------------------------------------
@@ -85,11 +94,11 @@ sub to_string {
 
     my $author   = $self->author;
     my @subdirs  = @{ $self->subdirs };
-    my $basename = $self->basename;
+    my $archive  = $self->archive;
 
     return join '/', $author,
                      @subdirs,
-                     $basename;
+                     $archive;
 }
 
 #------------------------------------------------------------------------------
@@ -99,7 +108,7 @@ __PACKAGE__->meta->make_immutable;
 #------------------------------------------------------------------------------
 1;
 
-
+__END__
 
 =pod
 
@@ -111,7 +120,7 @@ Pinto::DistributionSpec - Specifies a distribution by author and path fragments
 
 =head1 VERSION
 
-version 0.040_002
+version 0.065_01
 
 =head1 METHODS
 
@@ -137,7 +146,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
